@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: imap_proxy.c,v 1.7 2008/04/03 21:09:51 murch Exp $
+ * $Id: imap_proxy.c,v 1.11 2008/10/08 15:47:06 murch Exp $
  */
 
 #include <config.h>
@@ -106,7 +106,7 @@ static char *imap_parsemechlist(const char *str, struct protocol_t *prot)
 
 struct protocol_t imap_protocol =
 { "imap", "imap",
-  { 0, "* OK" },
+  { 1, NULL },
   { "C01 CAPABILITY", NULL, "C01 ", &imap_parsemechlist,
     { { " AUTH=", CAPA_AUTH },
       { " STARTTLS", CAPA_STARTTLS },
@@ -116,8 +116,8 @@ struct protocol_t imap_protocol =
       { " LIST-SUBSCRIBED", CAPA_LISTSUBSCRIBED },
       { " RIGHTS=kxte", CAPA_ACLRIGHTS },
       { NULL, 0 } } },
-  { "S01 STARTTLS", "S01 OK", "S01 NO" },
-  { "A01 AUTHENTICATE", 0, 0, "A01 OK", "A01 NO", "+ ", "*", NULL },
+  { "S01 STARTTLS", "S01 OK", "S01 NO", 0 },
+  { "A01 AUTHENTICATE", 0, 0, "A01 OK", "A01 NO", "+ ", "*", NULL, 0 },
   { "N01 NOOP", "* ", "N01 OK" },
   { "Q01 LOGOUT", "* ", "Q01 " }
 };
@@ -151,8 +151,8 @@ struct backend *proxy_findinboxserver(void)
 
 /* pipe_response() reads from 's->in' until either the tagged response
    starting with 'tag' appears, or if 'tag' is NULL, to the end of the
-   current line.  If 'include_tag' is set, the tagged line is included
-   in the output, otherwise the tagged line is stored in 's->last_result'. 
+   current line.  If 'include_last' is set, the last/tagged line is included
+   in the output, otherwise the last/tagged line is stored in 's->last_result'. 
    In either case, the result of the tagged command is returned.
 
    's->last_result' assumes that tagged responses don't contain literals.
@@ -161,7 +161,7 @@ struct backend *proxy_findinboxserver(void)
    force_notfatal says to not fatal() if we lose connection to backend_current
    even though it is in 95% of the cases, a good idea...
 */
-static int pipe_response(struct backend *s, const char *tag, int include_tag,
+static int pipe_response(struct backend *s, const char *tag, int include_last,
 			 int force_notfatal)
 {
     char buf[2048];
@@ -225,7 +225,7 @@ static int pipe_response(struct backend *s, const char *tag, int include_tag,
 		last = 1;
 	    }
 	
-	    if (last && !include_tag) {
+	    if (last && !include_last) {
 		/* Store the tagged line */
 		if (sl > s->last_result.alloc - s->last_result.len) {
 		    s->last_result.alloc =
@@ -248,14 +248,14 @@ static int pipe_response(struct backend *s, const char *tag, int include_tag,
 
 	    /* write out this part, but we have to keep reading until we
 	       hit the end of the line */
-	    if (!last || include_tag) prot_write(imapd_out, buf, sl);
+	    if (!last || include_last) prot_write(imapd_out, buf, sl);
 	    cont = 1;
 	    continue;
 	} else {		/* we got the end of the line */
 	    int i;
 	    int litlen = 0, islit = 0;
 
-	    if (!last || include_tag) prot_write(imapd_out, buf, sl);
+	    if (!last || include_last) prot_write(imapd_out, buf, sl);
 
 	    /* now we have to see if this line ends with a literal */
 	    if (sl < 64) {
@@ -291,7 +291,7 @@ static int pipe_response(struct backend *s, const char *tag, int include_tag,
 			/* EOF or other error */
 			return -1;
 		    }
-		    if (!last || include_tag) prot_write(imapd_out, buf, j);
+		    if (!last || include_last) prot_write(imapd_out, buf, j);
 		    litlen -= j;
 		}
 
@@ -317,7 +317,8 @@ int pipe_until_tag(struct backend *s, const char *tag, int force_notfatal)
     return pipe_response(s, tag, 0, force_notfatal);
 }
 
-int pipe_including_tag(struct backend *s, const char *tag, int force_notfatal) {
+int pipe_including_tag(struct backend *s, const char *tag, int force_notfatal)
+{
     int r;
 
     r = pipe_response(s, tag, 1, force_notfatal);
@@ -332,7 +333,7 @@ int pipe_including_tag(struct backend *s, const char *tag, int force_notfatal) {
 
 static int pipe_to_end_of_response(struct backend *s, int force_notfatal)
 {
-    return pipe_response(s, NULL, 0, force_notfatal);
+    return pipe_response(s, NULL, 1, force_notfatal);
 }
 
 /* copy our current input to 's' until we hit a true EOL.
@@ -910,7 +911,8 @@ void proxy_copy(const char *tag, char *sequence, char *name, int myrights,
     }
 
     /* start the append */
-    prot_printf(s->out, "%s Append {%d+}\r\n%s", tag, strlen(name), name);
+    prot_printf(s->out, "%s Append {" SIZE_T_FMT "+}\r\n%s",
+		tag, strlen(name), name);
     prot_printf(backend_current->out, "%s %s %s (Rfc822.peek)\r\n",
 		mytag, usinguid ? "Uid Fetch" : "Fetch", sequence);
     for (/* each FETCH response */;;) {
@@ -1104,7 +1106,7 @@ int proxy_catenate_url(struct backend *s, struct imapurl *url, FILE *f,
 
     /* select the mailbox (read-only) */
     proxy_gentag(mytag, sizeof(mytag));
-    prot_printf(s->out, "%s Examine {%d+}\r\n%s\r\n",
+    prot_printf(s->out, "%s Examine {" SIZE_T_FMT "+}\r\n%s\r\n",
 		mytag, strlen(url->mailbox), url->mailbox);
     for (/* each examine response */;;) {
 	/* read a line */
