@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: lmtpd.c,v 1.159 2008/04/11 20:07:00 murch Exp $
+ * $Id: lmtpd.c,v 1.161 2008/04/22 13:11:18 murch Exp $
  */
 
 #include <config.h>
@@ -154,8 +154,8 @@ static struct protocol_t lmtp_protocol =
       { "PIPELINING", CAPA_PIPELINING },
       { "IGNOREQUOTA", CAPA_IGNOREQUOTA },
       { NULL, 0 } } },
-  { "STARTTLS", "220", "454" },
-  { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL },
+  { "STARTTLS", "220", "454", 0 },
+  { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL, 0 },
   { "NOOP", NULL, "250" },
   { "QUIT", NULL, "221" }
 };
