@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: lmtpengine.c,v 1.127 2008/04/22 13:11:18 murch Exp $
+ * $Id: lmtpengine.c,v 1.129 2008/10/08 15:47:08 murch Exp $
  */
 
 #include <config.h>
@@ -684,9 +684,11 @@ static int savemsg(struct clientdata *cd,
     }
 
     /* We are always atleast "with LMTPA" -- no unauth delivery */
-    p += sprintf(p, " by %s (Cyrus %s) with LMTP%s%s",
-		 config_servername,
-		 CYRUS_VERSION,
+    p += sprintf(p, " by %s", config_servername);
+    if (config_serverinfo == IMAP_ENUM_SERVERINFO_ON) {
+	p += sprintf(p, " (Cyrus %s)", CYRUS_VERSION);
+    }
+    p += sprintf(p, " with LMTP%s%s",
 		 cd->starttls_done ? "S" : "",
 		 cd->authenticated != NOAUTH ? "A" : "");
 
@@ -701,7 +703,7 @@ static int savemsg(struct clientdata *cd,
  
     fprintf(f, "Received: ");
     for (i = 0, p = addbody; i < nfold; p = fold[i], i++) {
-	fprintf(f, "%.*s\r\n\t", fold[i] - p, p);
+	fprintf(f, "%.*s\r\n\t", (int) (fold[i] - p), p);
     }
     fprintf(f, "%s\r\n", p);
     spool_cache_header(xstrdup("Received"), addbody, m->hdrcache);
