@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mboxlist.c,v 1.257 2008/04/04 11:09:42 murch Exp $
+ * $Id: mboxlist.c,v 1.260 2008/10/08 15:47:08 murch Exp $
  */
 
 #include <config.h>
@@ -314,7 +314,7 @@ int mboxlist_update(char *name, int flags, const char *part, const char *acl,
 	r = mupdate_connect(config_mupdate_server, NULL, &mupdate_h, NULL);
 	if(r) {
 	    syslog(LOG_ERR,
-		   "can not connect to mupdate server for update of '%s'",
+		   "cannot connect to mupdate server for update of '%s'",
 		   name);
 	} else {
 	    r = mupdate_activate(mupdate_h, name, buf, acl);
@@ -387,7 +387,7 @@ mboxlist_mycreatemailboxcheck(char *name,
     if(!isadmin && force_user_create) return IMAP_PERMISSION_DENIED;
 
     /* User has admin rights over their own mailbox namespace */
-    if (mboxname_userownsmailbox(userid, name) && strchr(name+5, '.') &&
+    if (mboxname_userownsmailbox(userid, name) && strchr(mbox+5, '.') &&
 	(config_implicitrights & ACL_ADMIN)) {
 	isadmin = 1;
     }
@@ -505,7 +505,7 @@ mboxlist_mycreatemailboxcheck(char *name,
 	    if (mbox != name) {
 		/* add domain to identifier */
 		sprintf(identifier+strlen(identifier),
-			"@%.*s", mbox - name - 1, name);
+			"@%.*s", (int) (mbox - name - 1), name);
 	    }
 	    cyrus_acl_set(&acl, identifier, ACL_MODE_SET, ACL_ALL,
 		    (cyrus_acl_canonproc_t *)0, (void *)0);
@@ -638,7 +638,7 @@ int mboxlist_createmailbox(char *name, int mbtype, char *partition,
 	r = mupdate_connect(config_mupdate_server, NULL, &mupdate_h, NULL);
 	if(r) {
 	    syslog(LOG_ERR,
-		   "can not connect to mupdate server for reservation on '%s'",
+		   "cannot connect to mupdate server for reservation on '%s'",
 		   name);
 	    goto done;
 	}
@@ -1095,7 +1095,7 @@ int mboxlist_deletemailbox(const char *name, int isadmin, char *userid,
 	r = mupdate_connect(config_mupdate_server, NULL, &mupdate_h, NULL);
 	if(r) {
 	    syslog(LOG_ERR,
-		   "can not connect to mupdate server for delete of '%s'",
+		   "cannot connect to mupdate server for delete of '%s'",
 		   name);
 	    goto done;
 	}
@@ -1311,7 +1311,7 @@ int mboxlist_renamemailbox(char *oldname, char *newname, char *partition,
 	r = mupdate_connect(config_mupdate_server, NULL, &mupdate_h, NULL);
 	if(r) {
 	    syslog(LOG_ERR,
-		   "can not connect to mupdate server for rename of '%s'",
+		   "cannot connect to mupdate server for rename of '%s'",
 		   newname);
 	    goto done;
 	}
@@ -1573,7 +1573,7 @@ int mboxlist_setacl(const char *name, const char *identifier,
 		!strcmp(identifier, "anonymous") ||
 		!strcmp(identifier, "anyone")) {
 		snprintf(ident, sizeof(ident),
-			 "%.*s", cp - identifier, identifier);
+			 "%.*s", (int) (cp - identifier), identifier);
 	    } else {
 		strlcpy(ident, identifier, sizeof(ident));
 	    }
@@ -1729,7 +1729,7 @@ int mboxlist_setacl(const char *name, const char *identifier,
 	r = mupdate_connect(config_mupdate_server, NULL, &mupdate_h, NULL);
 	if(r) {
 	    syslog(LOG_ERR,
-		   "can not connect to mupdate server for reservation on '%s'",
+		   "cannot connect to mupdate server for reservation on '%s'",
 		   name);
 	} else {
 	    r = mupdate_activate(mupdate_h, name, buf, newacl);
@@ -1864,7 +1864,7 @@ mboxlist_sync_setacls(char *name, char *newacl)
 	r = mupdate_connect(config_mupdate_server, NULL, &mupdate_h, NULL);
 	if(r) {
 	    syslog(LOG_ERR,
-		   "can not connect to mupdate server for reservation on '%s'",
+		   "cannot connect to mupdate server for reservation on '%s'",
 		   name);
 	} else {
 	    r = mupdate_activate(mupdate_h, name, buf, newacl);
@@ -2172,7 +2172,7 @@ int mboxlist_findall(struct namespace *namespace __attribute__((unused)),
 		domainlen = strlen(p);
 	    }
 	    snprintf(domainpat+domainlen, sizeof(domainpat)-domainlen,
-		     "%.*s", p - pattern, pattern);
+		     "%.*s", (int) (p - pattern), pattern);
 	}
     }
 
