@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mupdate.c,v 1.102 2008/03/24 17:09:18 murch Exp $
+ * $Id: mupdate.c,v 1.106 2008/10/08 15:47:08 murch Exp $
  */
 
 #include <config.h>
@@ -156,8 +156,8 @@ struct conn {
 
     /* pending changes to send, in reverse order */
     pthread_mutex_t m;
-    pthread_cond_t cond;
     struct pending *plist;
+    struct pending *ptail;
     struct conn *updatelist_next;
     struct prot_waitevent *ev; /* invoked every 'update_wait' seconds
 				  to send out updates */
@@ -624,7 +624,7 @@ int service_init(int argc, char **argv,
 	 * to the slave.  We can probably fix this by prepending
 	 * config_servername onto the entries before updating the slaves.
 	 */
-	fatal("can not run mupdate master on a unified server", EC_USAGE);
+	fatal("cannot run mupdate master on a unified server", EC_USAGE);
     }
 
     if(pipe(conn_pipe) == -1) {
@@ -1547,6 +1547,7 @@ void log_update(const char *mailbox,
     for (upc = updatelist; upc != NULL; upc = upc->updatelist_next) {
 	/* for each connection, add to pending list */
 	struct pending *p = (struct pending *) xmalloc(sizeof(struct pending));
+	p->next = NULL;
 	strlcpy(p->mailbox, mailbox, sizeof(p->mailbox));
 	
 	/* this might need to be inside the mutex, but I doubt it */
@@ -1558,12 +1559,16 @@ void log_update(const char *mailbox,
 	    /* No Match! Continue! */
 	    continue;
 	}
-	
+
 	pthread_mutex_lock(&upc->m);
-	p->next = upc->plist;
-	upc->plist = p;
-	
-	pthread_cond_signal(&upc->cond);
+
+	if ( upc->plist == NULL ) {
+	    upc->plist = upc->ptail = p;
+	} else {
+	    upc->ptail->next = p;
+	    upc->ptail = p;
+	}
+
 	pthread_mutex_unlock(&upc->m);
     }
 }
@@ -1713,19 +1718,21 @@ void cmd_find(struct conn *C, const char *tag, const char *mailbox,
     pthread_mutex_unlock(&mailboxes_mutex); /* UNLOCK */
 
     if (m && m->t == SET_ACTIVE) {
-	prot_printf(C->pout, "%s MAILBOX {%d+}\r\n%s {%d+}\r\n%s {%d+}\r\n%s\r\n",
+	prot_printf(C->pout, "%s MAILBOX {" SIZE_T_FMT "+}\r\n%s"
+		    " {" SIZE_T_FMT "+}\r\n%s {" SIZE_T_FMT "+}\r\n%s\r\n",
 		    tag,
 		    strlen(m->mailbox), m->mailbox,
 		    strlen(m->server), m->server,
 		    strlen(m->acl), m->acl);
     } else if (m && m->t == SET_RESERVE) {
-	prot_printf(C->pout, "%s RESERVE {%d+}\r\n%s {%d+}\r\n%s\r\n",
+	prot_printf(C->pout, "%s RESERVE {" SIZE_T_FMT "+}\r\n%s"
+		    " {" SIZE_T_FMT "+}\r\n%s\r\n",
 		    tag,
 		    strlen(m->mailbox), m->mailbox,
 		    strlen(m->server), m->server);
     } else if (send_delete) {
 	/* not found, if needed, send a delete */
-	prot_printf(C->pout, "%s DELETE {%d+}\r\n%s\r\n",
+	prot_printf(C->pout, "%s DELETE {" SIZE_T_FMT "+}\r\n%s\r\n",
 		    tag, strlen(mailbox), mailbox);
     }
     
@@ -1768,14 +1775,16 @@ static int sendupdate(char *name,
 	    switch (m->t) {
 	    case SET_ACTIVE:
 		prot_printf(C->pout,
-			    "%s MAILBOX {%d+}\r\n%s {%d+}\r\n%s {%d+}\r\n%s\r\n",
+			    "%s MAILBOX {" SIZE_T_FMT "+}\r\n%s"
+			    " {" SIZE_T_FMT "+}\r\n%s {" SIZE_T_FMT "+}\r\n%s\r\n",
 			    C->streaming,
 			    strlen(m->mailbox), m->mailbox,
 			    strlen(m->server), m->server,
 			    strlen(m->acl), m->acl);
 		break;
 	    case SET_RESERVE:
-		prot_printf(C->pout, "%s RESERVE {%d+}\r\n%s {%d+}\r\n%s\r\n",
+		prot_printf(C->pout, "%s RESERVE {" SIZE_T_FMT "+}\r\n%s"
+			    " {" SIZE_T_FMT "+}\r\n%s\r\n",
 			    C->streaming,
 			    strlen(m->mailbox), m->mailbox,
 			    strlen(m->server), m->server);
@@ -1848,7 +1857,6 @@ void cmd_startupdate(struct conn *C, const char *tag,
     char pattern[2] = {'*','\0'};
 
     /* initialize my condition variable */
-    pthread_cond_init(&C->cond, NULL);
 
     /* The inital dump of the database can result in a lot of data,
      * let's do this nonblocking */
@@ -1889,6 +1897,7 @@ void sendupdates(struct conn *C, int flushnow)
     /* just grab the update list and release the lock */
     p = C->plist;
     C->plist = NULL;
+    C->ptail = NULL;
     pthread_mutex_unlock(&C->m);
 
     while (p != NULL) {
@@ -2244,6 +2253,7 @@ int mupdate_synchronize(mupdate_handle *handle)
     char pattern[] = { '*', '\0' };
     struct txn *tid = NULL;
     int ret = 0;    
+    int err = 0;
 
     if(!handle || !handle->saslcompleted) return 1;
 
@@ -2302,18 +2312,45 @@ int mupdate_synchronize(mupdate_handle *handle)
 	       strcmp(l->server, r->server) ||
 	       strcmp(l->acl,r->acl)) {
 		/* Something didn't match, replace it */
-		mboxlist_insertremote(r->mailbox, 
-				     (r->t == SET_RESERVE ?
-				        MBTYPE_RESERVE : 0),
-				      r->server, r->acl, &tid);
+		/*
+		 * If this is a locally hosted mailbox, don't make a
+		 * change, just warn.
+		 */
+		if ((config_mupdate_config == IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) &&
+			(strchr( l->server, '!' ) == NULL )) {
+		    syslog(LOG_ERR, "local mailbox %s wrong in mailbox list",
+			    l->mailbox );
+		    err++;
+		} else {
+		    mboxlist_insertremote(r->mailbox, 
+					 (r->t == SET_RESERVE ?
+					    MBTYPE_RESERVE : 0),
+					  r->server, r->acl, &tid);
+		}
 	    }
 	    /* Okay, dump these two */
 	    local_boxes.head = l->next;
 	    remote_boxes.head = r->next;
 	} else if (ret < 0) {
 	    /* Local without corresponding remote, delete it */
-	    if (config_mupdate_config != IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) {
-		/* But not for a unified configuration */
+		/*
+		 * In a unified murder, we don't want to delete locally
+		 * hosted mailboxes during mupdate's resync process.
+		 * If that sort of operation appears necessary, it
+		 * probably requires an operator to review it --
+		 * ctl_mboxlist is the right place to fix the kind
+		 * of configuration error implied.
+		 * 
+		 * A similar problem exists when the server thinks
+		 * it is locally hosting a mailbox, but mupdate master
+		 * thinks it's somewhere else.
+		 */
+	    if ((config_mupdate_config == IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) &&
+		    (strchr( l->server, '!' ) == NULL )) {
+		syslog(LOG_ERR, "local mailbox %s not in mailbox list",
+			l->mailbox );
+		err++;
+	    } else {
 		mboxlist_deleteremote(l->mailbox, &tid);
 	    }
 	    local_boxes.head = l->next;
@@ -2330,8 +2367,12 @@ int mupdate_synchronize(mupdate_handle *handle)
     if(l && !r) {
 	/* we have more deletes to do */
 	while(l) {
-	    if (config_mupdate_config != IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) {
-		/* But not for a unified configuration */
+	    if ((config_mupdate_config == IMAP_ENUM_MUPDATE_CONFIG_UNIFIED) &&
+		    (strchr( l->server, '!' ) == NULL )) {
+		syslog(LOG_ERR, "local mailbox %s not in mailbox list",
+			l->mailbox );
+		err++;
+	    } else {
 		mboxlist_deleteremote(l->mailbox, &tid);
 	    }
 	    local_boxes.head = l->next;
@@ -2352,7 +2393,12 @@ int mupdate_synchronize(mupdate_handle *handle)
     if (tid) mboxlist_commit(tid);
 
     /* All up to date! */
-    syslog(LOG_NOTICE, "mailbox list synchronization complete");
+    if ( err ) {
+	syslog(LOG_ERR, "mailbox list synchronization NOT complete (%d) errors",
+		err);
+    } else {
+	syslog(LOG_NOTICE, "mailbox list synchronization complete");
+    }
 
  done:
     pthread_mutex_unlock(&mailboxes_mutex); /* UNLOCK */
