@@ -41,7 +41,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: imtest.c,v 1.116 2008/04/11 12:35:18 murch Exp $
+ * $Id: imtest.c,v 1.120 2008/10/08 15:47:08 murch Exp $
  */
 
 #include "config.h"
@@ -194,7 +194,7 @@ struct tls_cmd_t {
     char *cmd;		/* tls command string */
     char *ok;		/* start tls prompt */
     char *fail;		/* failure response */
-    int auto_capa;      /* capa response given automatically after TLS */
+    int auto_capa;      /* capability response sent automatically after TLS */
 };
 
 struct sasl_cmd_t {
@@ -209,6 +209,8 @@ struct sasl_cmd_t {
     char *cancel;	/* cancel auth string */
     char *(*parse_success)(char *str);
 			/* [OPTIONAL] parse response for success data */
+    int auto_capa;      /* capability response sent automatically
+			   after AUTH with SASL security layer */
 };
 
 struct logout_cmd_t {
@@ -1454,14 +1456,22 @@ static void interactive(struct protocol_t *protocol, char *filename)
     return;
 }
 
+enum {
+    AUTO_BANNER = -1,
+    AUTO_NO = 0,
+    AUTO_YES = 1
+};
+
 static char *ask_capability(struct protocol_t *prot,
 			    int *supports_starttls, int automatic)
 {
-    char str[1024];
-    char *ret = NULL, *tmp;
+    char str[1024] = "";
+    char *ret = NULL, *tmp, *resp;
     
     *supports_starttls = 0;
 
+    resp = (automatic == AUTO_BANNER) ? prot->banner.resp : prot->capa_cmd.resp;
+
     if (!automatic) {
 	/* no capability command */
 	if (!prot->capa_cmd.cmd) return NULL;
@@ -1474,7 +1484,8 @@ static char *ask_capability(struct protocol_t *prot,
 
     do { /* look for the end of the capabilities */
 	if (prot_fgets(str, sizeof(str), pin) == NULL) {
-	    imtest_fatal("prot layer failure");
+	    if (!*str) imtest_fatal("prot layer failure");
+	    else break;
 	}
 	printf("S: %s", str);
 
@@ -1492,8 +1503,16 @@ static char *ask_capability(struct protocol_t *prot,
 	    else
 		ret = strdup(tmp+strlen(prot->capa_cmd.auth));
 	}
-    } while (strncasecmp(str, prot->capa_cmd.resp, strlen(prot->capa_cmd.resp)));
+
+	if (!resp) {
+	    /* multiline response with no distinct end (IMAP banner) */
+	    prot_NONBLOCK(pin);
+	}
+
+ 	/* look for the end of the capabilities */
+    } while (!resp || strncasecmp(str, resp, strlen(resp)));
     
+    prot_BLOCK(pin);
     return ret;
 }
 
@@ -1782,7 +1801,8 @@ static int append_msg(char *mbox, int size)
 {
     int lup;
     
-    prot_printf(pout,"A003 APPEND %s (\\Seen) {%u}\r\n",mbox,size+strlen(HEADERS));
+    prot_printf(pout,"A003 APPEND %s (\\Seen) {" SIZE_T_FMT "}\r\n",
+		mbox,size+strlen(HEADERS));
     /* do normal header foo */
     prot_printf(pout,HEADERS);
     
@@ -2205,10 +2225,10 @@ void usage(char *prog, char *prot)
 
 static struct protocol_t protocols[] = {
     { "imap", "imaps", "imap",
-      { 0, "* OK", NULL },
+      { 1, NULL, NULL },
       { "C01 CAPABILITY", "C01 ", " STARTTLS", " AUTH=", &imap_parse_mechlist },
       { "S01 STARTTLS", "S01 OK", "S01 NO", 0 },
-      { "A01 AUTHENTICATE", 0, 0, "A01 OK", "A01 NO", "+ ", "*", NULL },
+      { "A01 AUTHENTICATE", 0, 0, "A01 OK", "A01 NO", "+ ", "*", NULL, 0 },
       &imap_do_auth, { "Q01 LOGOUT", "Q01 " },
       &imap_init_conn, &generic_pipe, &imap_reset
     },
@@ -2216,21 +2236,21 @@ static struct protocol_t protocols[] = {
       { 0, "+OK ", &pop3_parse_banner },
       { "CAPA", ".", "STLS", "SASL ", NULL },
       { "STLS", "+OK", "-ERR", 0 },
-      { "AUTH", 255, 0, "+OK", "-ERR", "+ ", "*", NULL },
+      { "AUTH", 255, 0, "+OK", "-ERR", "+ ", "*", NULL, 0 },
       &pop3_do_auth, { "QUIT", "+OK" }, NULL, NULL, NULL
     },
     { "nntp", "nntps", "nntp",
       { 0, "20", NULL },
       { "CAPABILITIES", ".", "STARTTLS", "SASL ", NULL },
       { "STARTTLS", "382", "580", 0 },
-      { "AUTHINFO SASL", 512, 0, "28", "48", "383 ", "*", &nntp_parse_success },
+      { "AUTHINFO SASL", 512, 0, "28", "48", "383 ", "*", &nntp_parse_success, 0 },
       &nntp_do_auth, { "QUIT", "205" }, NULL, NULL, NULL
     },
     { "lmtp", NULL, "lmtp",
       { 0, "220 ", NULL },
       { "LHLO lmtptest", "250 ", "STARTTLS", "AUTH ", NULL },
       { "STARTTLS", "220", "454", 0 },
-      { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL },
+      { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL, 0 },
       &xmtp_do_auth, { "QUIT", "221" },
       &xmtp_init_conn, &generic_pipe, &xmtp_reset
     },
@@ -2238,7 +2258,7 @@ static struct protocol_t protocols[] = {
       { 0, "220 ", NULL },
       { "EHLO smtptest", "250 ", "STARTTLS", "AUTH ", NULL },
       { "STARTTLS", "220", "454", 0 },
-      { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL },
+      { "AUTH", 512, 0, "235", "5", "334 ", "*", NULL, 0 },
       &xmtp_do_auth, { "QUIT", "221" },
       &xmtp_init_conn, &generic_pipe, &xmtp_reset
     },
@@ -2246,28 +2266,28 @@ static struct protocol_t protocols[] = {
       { 1, "* OK", NULL },
       { NULL , "* OK", "* STARTTLS", "* AUTH ", NULL },
       { "S01 STARTTLS", "S01 OK", "S01 NO", 1 },
-      { "A01 AUTHENTICATE", INT_MAX, 1, "A01 OK", "A01 NO", "", "*", NULL },
+      { "A01 AUTHENTICATE", INT_MAX, 1, "A01 OK", "A01 NO", "", "*", NULL, 0 },
       NULL, { "Q01 LOGOUT", "Q01 " }, NULL, NULL, NULL
     },
     { "sieve", NULL, SIEVE_SERVICE_NAME,
       { 1, "OK", NULL },
       { "CAPABILITY", "OK", "\"STARTTLS\"", "\"SASL\" ", NULL },
       { "STARTTLS", "OK", "NO", 1 },
-      { "AUTHENTICATE", INT_MAX, 1, "OK", "NO", NULL, "*", &sieve_parse_success },
+      { "AUTHENTICATE", INT_MAX, 1, "OK", "NO", NULL, "*", &sieve_parse_success, 1 },
       NULL, { "LOGOUT", "OK" }, NULL, NULL, NULL
     },
     { "csync", NULL, "csync",
       { 1, "* OK", NULL },
       { NULL , "* OK", "* STARTTLS", "* SASL ", NULL },
       { "STARTTLS", "OK", "NO", 1 },
-      { "AUTHENTICATE", INT_MAX, 0, "OK", "NO", "+ ", "*", NULL },
+      { "AUTHENTICATE", INT_MAX, 0, "OK", "NO", "+ ", "*", NULL, 0 },
       NULL, { "EXIT", "OK" }, NULL, NULL, NULL
     },
     { NULL, NULL, NULL,
       { 0, NULL, NULL },
       { NULL, NULL, NULL, NULL, NULL },
       { NULL, NULL, NULL, 0 },
-      { NULL, 0, 0, NULL, NULL, NULL, NULL, NULL },
+      { NULL, 0, 0, NULL, NULL, NULL, NULL, NULL, 0 },
       NULL, { NULL, NULL }, NULL, NULL, NULL
     }
 };
@@ -2279,7 +2299,7 @@ int main(int argc, char **argv)
     char servername[1024];
     char *filename=NULL;
     
-    char *mechlist;
+    char *mechlist = NULL;
     unsigned ext_ssf = 0;
     const void *ssfp;
     sasl_ssf_t ssf;
@@ -2453,7 +2473,7 @@ int main(int argc, char **argv)
 	imtest_fatal("unknown protocol\n");
     
     if (dossl && !protocol->sprotocol)
-	imtest_fatal("protocol can not be SSL-wrapped\n");
+	imtest_fatal("protocol cannot be SSL-wrapped\n");
 
     if (run_stress_test && strcmp(protocol->protocol, "imap"))
 	imtest_fatal("stress test can only be run for IMAP\n");
@@ -2511,7 +2531,7 @@ int main(int argc, char **argv)
 	}
 
 	if (init_net(servername, port) != IMTEST_OK) {
-	    imtest_fatal("Network initialization - can not connect to %s:%s",
+	    imtest_fatal("Network initialization - cannot connect to %s:%s",
 			 servername, port);
 	}
     
@@ -2532,7 +2552,12 @@ int main(int argc, char **argv)
 #endif /* HAVE_SSL */
 
 	if (protocol->banner.is_capa) {
-	    mechlist = ask_capability(protocol, &server_supports_tls, 1);
+	    /* try to get the capabilities from the banner */
+	    mechlist = ask_capability(protocol, &server_supports_tls, AUTO_BANNER);
+	    if (!mechlist && !server_supports_tls) {
+		/* found no capabilities in banner -> get them explicitly */
+		protocol->banner.is_capa = 0;
+	    }
 	}
 	else {
 	    do { /* look for the banner response */
@@ -2546,8 +2571,9 @@ int main(int argc, char **argv)
 		    rock = protocol->banner.parse_banner(str);
 	    } while (strncasecmp(str, protocol->banner.resp,
 				 strlen(protocol->banner.resp)));
-	
-	    mechlist = ask_capability(protocol, &server_supports_tls, 0);
+	}	
+	if (!protocol->banner.is_capa) {
+	    mechlist = ask_capability(protocol, &server_supports_tls, AUTO_NO);
 	}
 	
 #ifdef HAVE_SSL
@@ -2618,6 +2644,15 @@ int main(int argc, char **argv)
 	    printf("SSF: unable to determine (SASL ERROR %d)\n", result);
 	} else {
 	    printf("Security strength factor: %d\n", ext_ssf + ssf);
+
+	    if (ssf && protocol->sasl_cmd.auto_capa) {
+		/* ask for the capabilities again */
+		if (verbose==1)
+		    printf("Asking for capabilities again "
+			   "since they might have changed\n");
+		mechlist = ask_capability(protocol, &server_supports_tls, 1);
+		if (mechlist) free(mechlist);
+	    }
 	}
 
     } while (--reauth);
